@@ -8,6 +8,7 @@
 #' @importFrom utils read.csv
 #' @import XML
 #' @import httr
+#' @import jsonlite
 #' @export
 #' @keywords ISO metadata element
 #' @return Object of \code{\link{R6Class}} for modelling an ISO Metadata Element
@@ -162,8 +163,7 @@ ISOAbstractObject <- R6Class("ISOAbstractObject",
     system_fields = c("wrap", "valueDescription",
                       "element", "namespace", "defaults", "attrs", "printAttrs",
                       "codelistId", "measureType", "isNull", "anyElement"),
-    xmlComments = function(isoCompliant = NA,
-                           inspireCompliant = NA, inspireCompleteness = NA, inspireReportURL = NA){
+    xmlComments = function(isoCompliant = NA, inspireReport = NULL){
       comments <- list()
       geometa <- packageDescription("geometa")
       title <- paste0("ISO 19139 XML generated by geometa R package - Version ", geometa$Version)
@@ -171,10 +171,8 @@ ISOAbstractObject <- R6Class("ISOAbstractObject",
       isISOCompliant <- ifelse(is.na(isoCompliant),"NOT TESTED", ifelse(isoCompliant, "YES", "NO"))
       ISOCompliance <- paste0("ISO 19139 XML compliance: ", isISOCompliant)
       
-      isINSPIRECompliant <- ifelse(is.na(inspireCompliant), "NOT TESTED", ifelse(inspireCompliant, "YES", "NO"))
+      isINSPIRECompliant <- ifelse(is.null(inspireReport), "NOT TESTED", ifelse(inspireReport$Status=="PASSED", "YES", "NO"))
       INSPIRECompliance <- paste0("INSPIRE compliance: ", isINSPIRECompliant)
-      INSPIRECompleteness <- paste0("INSPIRE completeness: ", inspireCompleteness, "%")
-      INSPIREReport <- paste0("INSPIRE Report: ", inspireReportURL)
       
       createdOn <- paste0("Metadata Creation date/time: ", format(Sys.time(), "%Y-%m-%dT%H:%M:%S"))
       geometaAuthor <- gsub(">","",gsub("<","",unlist(strsplit(as.character(eval(parse(text=geometa$Authors)))," \\["))[1]))
@@ -185,10 +183,14 @@ ISOAbstractObject <- R6Class("ISOAbstractObject",
       comments[[idx]] <- createdOn; idx <- idx+1
       comments[[idx]] <- title; idx <- idx+1
       comments[[idx]] <- ISOCompliance; idx <- idx+1
-      if(!is.na(inspireCompliant)){
+      if(!is.null(inspireReport)){
         comments[[idx]] <- INSPIRECompliance; idx <- idx+1
-        comments[[idx]] <- INSPIRECompleteness;idx <- idx+1
-        comments[[idx]] <- INSPIREReport;idx <- idx+1
+        for(inspireAttr in names(inspireReport)){
+          if(!(inspireAttr %in% c("raw", "status"))){
+            comments[[idx]] <- sprintf("INSPIRE %s : %s", inspireAttr, inspireReport[[inspireAttr]])
+            idx <- idx+1
+          }
+        }
       }
       comments[[idx]] <- paste("geometa R package information:", author, infoPage, bugReport, sep="\n")
       return(comments)
@@ -543,8 +545,9 @@ ISOAbstractObject <- R6Class("ISOAbstractObject",
                   }
                 }
               }else{
-                xmlNamespacePrefix <- "GML"
-                if(startsWith(nsPrefix,"gml")) xmlNamespacePrefix <- toupper(nsPrefix)
+                #xmlNamespacePrefix <- "GML"
+                #if(startsWith(nsPrefix,"gml")) xmlNamespacePrefix <- toupper(nsPrefix)
+                xmlNamespacePrefix <- self$getClass()$private_fields$xmlNamespacePrefix
                 gmlElem <- GMLElement$new(element = fieldName, xmlNamespacePrefix = xmlNamespacePrefix)
                 gmlElem$decode(xml = childElement)
                 if(is(self[[fieldName]], "list")){
@@ -554,8 +557,10 @@ ISOAbstractObject <- R6Class("ISOAbstractObject",
                 }
               }
             }else{
-              xmlNamespacePrefix <- "GML"
-              if(startsWith(nsPrefix,"gml")) xmlNamespacePrefix <- toupper(nsPrefix)
+              #xmlNamespacePrefix <- "GML"
+              #if(startsWith(nsPrefix,"gml")) xmlNamespacePrefix <- toupper(nsPrefix)
+              xmlNamespacePrefix <- self$getClass()$private_fields$xmlNamespacePrefix
+              if(is.null(xmlNamespacePrefix)) xmlNamespacePrefix <- "GML"
               gmlElem <- GMLElement$new(element = fieldName, xmlNamespacePrefix = xmlNamespacePrefix)
               gmlElem$decode(xml = childElement)
               if(is(self[[fieldName]], "list")){
@@ -929,11 +934,7 @@ ISOAbstractObject <- R6Class("ISOAbstractObject",
         if(!inspire){
           header_comments <- private$xmlComments(compliant)
         }else{
-          header_comments <- private$xmlComments(compliant$ISO,
-                              compliant$INSPIRE$validity$completeness$status, 
-                              compliant$INSPIRE$validity$completeness$percentage,
-                              compliant$INSPIRE$url
-                             )
+          header_comments <- private$xmlComments(compliant$ISO, compliant$INSPIRE)
         }
         #process XML comments
         for(comment in header_comments){
@@ -996,11 +997,17 @@ ISOAbstractObject <- R6Class("ISOAbstractObject",
       
       if(inspire){
         inspireValidator <- INSPIREMetadataValidator$new()
-        inspireReport <- inspireValidator$getValidationReport(obj = self)
-        isValid <- list(
-          ISO = isValid,
-          INSPIRE = inspireReport
-        )        
+        if(!inspireValidator$running){
+          self$WARN("INSPIRE Reference validator web-service is currently down. Skipping INSPIRE validation")
+          inspire <- FALSE
+        }
+        if(inspire){
+          inspireReport <- inspireValidator$getValidationReport(obj = self)
+          isValid <- list(
+            ISO = isValid,
+            INSPIRE = inspireReport
+          )
+        }
       }
       
       return(isValid)
@@ -1381,7 +1388,11 @@ ISOAbstractObject$getISOClassByNode = function(node){
   if(length(nodeElementNames)>1){
     nodeElementName <- nodeElementNames[2]
   }
-  list_of_classes <- ISOAbstractObject$getISOClasses(extended = TRUE, pretty = FALSE)
+  
+  list_of_classes <- getISOClasses()
+  if(is.null(list_of_classes))
+    list_of_classes <- ISOAbstractObject$getISOClasses(extended = TRUE, pretty = FALSE)
+   
   for(classname in list_of_classes){
     clazz <- try(eval(parse(text=classname)))
     if(nodeElementName %in% clazz$private_fields$xmlElement){
@@ -1444,3 +1455,44 @@ ISOAbstractObject$compare = function(metadataElement1, metadataElement2){
   }
   return(text1 == text2)
 }
+
+#' @name cacheISOClasses
+#' @aliases cacheISOClasses
+#' @title cacheISOClasses
+#' @export
+#' @description \code{\link{cacheISOClasses}} allows to cache the list of
+#' \pkg{geometa} classes or extended. This is especially required to fasten
+#' the decoding of metadata elements from an XML file. It is called internally
+#' by \pkg{geometa} the first function \code{\link{getISOClasses}} is called 
+#' and each time the function \code{\link{readISO19139}} function is called to 
+#' integrate eventually new classes added by user to extend \pkg{geometa} model 
+#' (case of ISO profiles).
+#' 
+#' @usage cacheISOClasses()
+#' 
+#' @examples             
+#'   cacheISOClasses()
+#' 
+#' @author Emmanuel Blondel, \email{emmanuel.blondel1@@gmail.com}
+#
+cacheISOClasses <- function(){
+  .geometa.iso$classes <- ISOAbstractObject$getISOClasses(extended = TRUE, pretty = FALSE)
+}
+
+#' @name getISOClasses
+#' @aliases getISOClasses
+#' @title getISOClasses
+#' @export
+#' @description get the list of cached ISO classes
+#' 
+#' @usage getISOClasses()
+#' 
+#' @examples             
+#'   getISOClasses()
+#' 
+#' @author Emmanuel Blondel, \email{emmanuel.blondel1@@gmail.com}
+#
+getISOClasses <- function(){
+  if(length(.geometa.iso$classes)==0) cacheISOClasses()
+  return(.geometa.iso$classes)
+}
