@@ -6,17 +6,19 @@
 #' @keywords ISO temporal extent
 #' @return Object of \code{\link{R6Class}} for modelling an ISO TemporalExtent
 #' @format \code{\link{R6Class}} object.
+#' 
+#' @field extent [\code{\link{GMLTimeInstant}}|\code{\link{GMLTimePeriod}}] the temporal extent (instant or period)
 #'
 #' @section Methods:
 #' \describe{
 #'  \item{\code{new(xml)}}{
-#'    This method is used to instantiate an ISOTemporalExtent
+#'    This method is used to instantiate an \code{\link{ISOTemporalExtent}}
 #'  }
 #'  \item{\code{setTimeInstant(timeInstant)}}{
-#'    Sets a time instant
+#'    Sets a time instant, object of class \code{\link{GMLTimeInstant}}
 #'  }
 #'  \item{\code{setTimePeriod(timePeriod)}}{
-#'    Sets a time period
+#'    Sets a time period, object of class \code{\link{GMLTimePeriod}}
 #'  }
 #' }
 #' 
@@ -46,7 +48,9 @@ ISOTemporalExtent <- R6Class("ISOTemporalExtent",
     
     #setTimeInstant
     setTimeInstant = function(timeInstant){
-      stop("Not yet implemented")
+      if(!is(timeInstant, "GMLTimeInstant")){
+        stop("Value should be an object of class 'GMLTimeInstant'")
+      }
       self$extent = timeInstant
     },
     
