@@ -9,7 +9,8 @@ require(testthat)
 context("ISOAnchor")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOAnchor$new(name = "some entity name", href = "someentityuri")
   xml <- md$encode()
