@@ -9,7 +9,8 @@ require(testthat)
 context("ISOGeometricObjects")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOGeometricObjects$new()
   md$setGeometricObjectType("surface")
