@@ -9,7 +9,8 @@ require(testthat)
 context("ISOURL")
 
 test_that("encoding",{
-  
+  testthat::skip_on_cran()
+  testthat::skip_on_travis()
   #encoding
   md <- ISOURL$new(value = "myvalue")
   expect_is(md, "ISOURL")
